@@ -1,5 +1,5 @@
 """
-   Copyright 2019 Leah Campbell
+   Copyright 2024 Leah Campbell and Ian Housman
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -21,14 +21,9 @@
 #           ASSETMANAGERLIB.PY
 #--------------------------------------------------------------------------
 
-import sys, ee, os, shutil, subprocess, datetime, calendar, json
+import geeViz.geeView 
+import sys, ee, os, shutil, subprocess, datetime, calendar, json,glob
 import time, logging, pdb
-try:
-    z = ee.Number(1).getInfo()
-except:
-    print('Initializing GEE')
-    ee.Initialize()
-
 taskLimit = 10
 
 #############################################################################################
@@ -38,8 +33,11 @@ taskLimit = 10
 #Function for updating ACL for a given GEE asset path
 def updateACL(assetName,writers = [],all_users_can_read = True,readers = []):
     print('Updating permissions for: ',assetName)
-    ee.data.setAssetAcl(assetName, json.dumps({u'writers': writers, u'all_users_can_read': all_users_can_read, u'readers': readers}))
-
+    try:
+        ee.data.setAssetAcl(assetName, json.dumps({u'writers': writers, u'all_users_can_read': all_users_can_read, u'readers': readers}))
+    except Exception as E:
+        print('Could not update permissions for: ',assetName)
+        print(E)
 #--------------------------------------------------------------------------------------------
 
 #Function for updating all assets under a given folder level in GEE
@@ -88,11 +86,15 @@ def batchCopy(fromFolder,toFolder,outType = 'imageCollection'):
 
     for image in images:
         out = toFolder +'/'+ base(image)
-        print( out)
-        try:
-            ee.data.copyAsset(image,out)
-        except:
-            print( out,'Error: May already exist')
+        if not ee_asset_exists(out):
+            print('Copying: ',image)
+            try:
+                ee.data.copyAsset(image,out)
+            except Exception as E:
+                print('Could not copy: ',image)
+                print(E)
+        else:
+            print(out,' already exists')
 
 def copyByName(fromFolder, toFolder, nameIdentifier, outType = 'imageCollection'):
 
@@ -120,16 +122,19 @@ def copyByName(fromFolder, toFolder, nameIdentifier, outType = 'imageCollection'
                 print( out,'Error: May already exist')
 #---------------------------------------------------------------------------------------------
 
-def moveImages(images,toFolder):
+def moveImages(images,toFolder,delete_original = False):
     create_image_collection(toFolder)
     for image in images:
         print ('Copying',base(image))
         out = toFolder + '/' + base(image)
-        try:
-            ee.data.copyAsset(image,out)
-            #ee.data.deleteAsset(image)
-        except:
-            print (out,'already exists')
+        if not ee_asset_exists(out):
+            try:
+                ee.data.copyAsset(image,out)
+                if delete_original:
+                    ee.data.deleteAsset(image)
+            except Exception as E:
+                print('Error copying:', image)
+                print(E)
 
 #---------------------------------------------------------------------------------------------
 # types = 'imageCollection' or 'tables'
@@ -142,7 +147,11 @@ def batchDelete(Collection, type = 'imageCollection'):
 
     for image in images:
         print('Deleting: '+ Collection +'/'+ base(image))
-        ee.data.deleteAsset(image)
+        try:
+            ee.data.deleteAsset(image)
+        except Exception as E:
+            print('Could not delete: ',image)
+            print(E)
 
 def deleteByName(Collection, nameIdentifier, type='imageCollection'):
     if type == 'imageCollection':
@@ -153,7 +162,11 @@ def deleteByName(Collection, nameIdentifier, type='imageCollection'):
     for image in images:
         if nameIdentifier in image:
             print('Deleting: '+ Collection +'/'+ base(image))
-            ee.data.deleteAsset(image)
+            try:
+                ee.data.deleteAsset(image)
+            except Exception as E:
+                print('Could not delete: ',image)
+                print(E)
 #############################################################################################
 #       Asset Info Queries
 #############################################################################################
@@ -191,8 +204,7 @@ def assetsize(asset):
         print('')
         print(str(asset)+" ===> "+str(size))
         print('Total number of items in folder: '+str(len(num.split('\n'))-1))
-if __name__ == '__main__':
-    assetsize(None)
+
 #############################################################################################
 #       Functions to Upload to Google Cloud Storage and Google Earth Engine Repository
 #############################################################################################
@@ -217,7 +229,7 @@ def upload_to_gee(image_dir, gs_bucket,asset_dir,image_extension = '.tif', resam
     create_image_collection(asset_dir)
 
     #Get the names that need to be transferred form GCS to EE
-    tifs = glob(image_dir,image_extension)
+    tifs = glob.glob(os.path.join(image_dir,image_extension))
 
     #Set up the asset dir, files, and band names object
     asset_dir = check_end(asset_dir)
@@ -285,20 +297,21 @@ def check_end(in_path, add = '/'):
 ##############################################################################################
 #Returns all files containing an extension or any of a list of extensions
 #Can give a single extension or a list of extensions
-def glob(Dir, extension):
-    Dir = check_end(Dir)
-    if type(extension) != list:
-        if extension.find('*') == -1:
-            return map(lambda i : Dir + i, filter(lambda i: os.path.splitext(i)[1] == extension, os.listdir(Dir)))
-        else:
-            return map(lambda i : Dir + i, os.listdir(Dir))
-    else:
-        out_list = []
-        for ext in extension:
-            tl = map(lambda i : Dir + i, filter(lambda i: os.path.splitext(i)[1] == ext, os.listdir(Dir)))
-            for l in tl:
-                out_list.append(l)
-        return out_list
+# use glob.glob
+# def glob(Dir, extension):
+#     Dir = check_end(Dir)
+#     if type(extension) != list:
+#         if extension.find('*') == -1:
+#             return map(lambda i : Dir + i, filter(lambda i: os.path.splitext(i)[1] == extension, os.listdir(Dir)))
+#         else:
+#             return map(lambda i : Dir + i, os.listdir(Dir))
+#     else:
+#         out_list = []
+#         for ext in extension:
+#             tl = map(lambda i : Dir + i, filter(lambda i: os.path.splitext(i)[1] == ext, os.listdir(Dir)))
+#             for l in tl:
+#                 out_list.append(l)
+#         return out_list
 ##############################################################################################
 #Function to get filename without extension
 def base(in_path):
@@ -399,9 +412,41 @@ def create_image_collection(full_path_to_collection):
     if ee_asset_exists(full_path_to_collection):
         print("Collection "+full_path_to_collection+" already exists")
     else:
-        ee.data.createAsset({'type': ee.data.ASSET_TYPE_IMAGE_COLL}, full_path_to_collection)
-        print('New collection '+full_path_to_collection+' created')
+        try:
+            ee.data.createAsset({'type': ee.data.ASSET_TYPE_IMAGE_COLL}, full_path_to_collection)
+            print('New collection '+full_path_to_collection+' created')
+        except Exception as E:
+            print('Could not create: ',full_path_to_collection)
+            print(E)
+            
+# More general function to create asset collecctions or folders
+# asset_type can be one of ee.data.ASSET_TYPE_FOLDER or ee.data.ASSET_TYPE_IMAGE_COLL
+# If nested folders that do not already exist are provided, they will be created unless recursive = False
+def create_asset(asset_path,asset_type = ee.data.ASSET_TYPE_FOLDER,recursive=True):
 
+    # Find the root and all nested folders
+    project_root = f'{asset_path.split("assets")[0]}assets'
+    sub_directories = f'{asset_path.split("assets/")[1]}'.split('/')
+    
+    # If there is more than 1 level of folder, try to make them
+    if len(sub_directories) > 1 and recursive:
+        print('Found the following sub directories: ',sub_directories)
+        print('Will attempt to create them if they do not exist')
+        path_temp = project_root
+        for sub_directory in sub_directories[:-1]:
+            path_temp = f'{path_temp}/{sub_directory}'
+            create_asset(path_temp,asset_type = ee.data.ASSET_TYPE_FOLDER,recursive = False)
+
+    if ee_asset_exists(asset_path):
+        print("Asset "+asset_path+" already exists")
+    else:
+        try:
+            print(asset_path)
+            ee.data.createAsset({'type': asset_type}, asset_path)
+            print('New asset '+asset_path+' created')
+        except Exception as E:
+            print('Could not create: ',asset_path)
+            print(E)
 def verify_path(path):
     response = ee.data.getInfo(path)
     if not response:
@@ -463,4 +508,94 @@ def julian_to_calendar(julian_date, year):
         ldn = str(dn)
     return [year,mn,dn]
 ##############################################################################################
+# Functions to set date
+def getDate(year,month,day):
+   return datetime.datetime(year,month,day).isoformat()+'Z'
+def setDate(assetPath,year,month,day):
+   ee.data.updateAsset(assetPath, {'start_time':getDate(year,month,day)},['start_time'])
 
+
+#########################################################################
+# Function to ingest tif from Google Cloud Storage as an asset
+# Follows guidance from: https://developers.google.com/earth-engine/guides/image_manifest
+# Must have bandNames specified for pyramiding policy and no data values to be set
+# Band names must be one name for each band in images that will be uploaded
+# pyramidingPolicy and noDataValues can be one for each band name or only one (that is then repeated for each band)
+# The system:time_start and system:time_end properties are handled automatically assuming the proper format or ee Date object is provided
+def ingestImageFromGCS(gcsURIs,assetPath,overwrite = False,bandNames = None,properties = None,pyramidingPolicy=None,noDataValues=None):
+    if overwrite or not ee_asset_exists(assetPath):
+        taskID= ee.data.newTaskId(1)[0]
+
+        #Make sure collection or folder exists
+        create_image_collection(os.path.dirname(assetPath))
+
+        # Handle if single image path is provided - changes to a list
+        if str(type(gcsURIs)).find("'str'")>-1:
+            gcsURIs = [gcsURIs]
+
+        # Repeat the pyramiding policy and no data value if only one is provided
+        if bandNames != None and pyramidingPolicy != None and str(type(pyramidingPolicy)).find("'str'")>-1:
+            pyramidingPolicy = [pyramidingPolicy]*len(bandNames)
+
+        if bandNames != None and noDataValues != None and str(type(noDataValues)).find("'list'")==-1:
+            noDataValues = [noDataValues]*len(bandNames)
+            
+        # Set up the manifest
+        params = {
+            'name' :assetPath,
+            'tilesets' :[{'sources': 
+                            [{'uris': gcsURIs}]   
+                        }]
+            }
+        # Set up the band names, pyramiding policy, and no data values
+        if bandNames !=None:
+            bnDict = []
+            for i,bn in enumerate(bandNames):
+                bnDictT = {'id': bn,'tileset_band_index':i}
+                if pyramidingPolicy != None:
+                    bnDictT['pyramiding_policy']= pyramidingPolicy[i]
+                if noDataValues != None:
+                    bnDictT['missing_data']= {'values':[noDataValues[i]]}
+                bnDict.append(bnDictT) 
+            params['bands'] = bnDict
+
+        # Handle the date inconsistency in the GEE API
+        def fixDate(propIn,propOut):
+            if propIn in properties.keys():
+                d = properties[propIn]
+                if str(type(d)).find('ee.ee_date.Date')>-1:
+                    d = d.format('YYYY-MM-dd').cat('T').cat(d.format('HH:mm:SS')).cat('Z').getInfo()
+                params[propOut] = d
+                properties.pop(propIn)
+            
+        if properties !=None:
+            fixDate('system:time_start','start_time')
+            fixDate('system:time_end','end_time')
+            params['properties'] = properties
+        print('Ingestion manifest:',params)   
+            
+        ee.data.startIngestion(taskID, params,overwrite)
+        print('Starting ingestion task:',assetPath)
+    else:
+        print(assetPath,'already exists')
+#########################################################################
+# Function to wrap the entire uploading an image to GEE image asset workflow
+# First uploads to an existing GCS bucket, and then ingests to GEE
+# Can handle multiple multi-band image tiles or a single image
+# Must have bandNames specified for pyramiding policy and no data values to be set
+# Band names must be one name for each band in images that will be uploaded
+# pyramidingPolicy and noDataValues can be one for each band name or only one (that is then repeated for each band)
+# The system:time_start and system:time_end properties are handled automatically assuming the proper format or ee Date object is provided
+def uploadToGEEImageAsset(localTif,gcsBucket,assetPath,overwrite = False,bandNames = None,properties = None,pyramidingPolicy=None,noDataValues=None,gsutil_path='C:/Program Files (x86)/Google/Cloud SDK/google-cloud-sdk/bin/gsutil.cmd'):
+  # List all local files with specified name or wildcard name and make GCS paths for each file
+  localTifs = glob.glob(localTif)
+  gcsURIs = [gcsBucket+'/'+os.path.basename(tif) for tif in localTifs]
+
+  # Upload files to GCS (will not overwrite)
+  uploadCommand = '"{}" -m cp -n -r {} {}'.format(gsutil_path,localTif,gcsBucket)
+  call = subprocess.Popen(uploadCommand)
+  call.wait()
+
+  # Ingest to GEE
+  ingestImageFromGCS(gcsURIs,assetPath,overwrite = overwrite,bandNames = bandNames,properties = properties,pyramidingPolicy=pyramidingPolicy,noDataValues=noDataValues)
+#########################################################################
\ No newline at end of file
